@@ -1,3 +1,8 @@
+class CreateUserException(Exception):
+    def __init__(self, field_to_errors):
+        self.field_to_errors = field_to_errors
+
+
 class UnauthorizedException(Exception):
     def __init__(self, message):
         self.message = message
